summaryrefslogtreecommitdiffstats
path: root/kmail/rulewidgethandlermanager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/rulewidgethandlermanager.cpp')
-rw-r--r--kmail/rulewidgethandlermanager.cpp88
1 files changed, 44 insertions, 44 deletions
diff --git a/kmail/rulewidgethandlermanager.cpp b/kmail/rulewidgethandlermanager.cpp
index 75940e4c..b3e211fa 100644
--- a/kmail/rulewidgethandlermanager.cpp
+++ b/kmail/rulewidgethandlermanager.cpp
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -228,12 +228,12 @@ void KMail::RuleWidgetHandlerManager::unregisterHandler( const RuleWidgetHandler
}
namespace {
/** Returns the number of immediate children of parent with the given object
name. Used by RuleWidgetHandlerManager::createWidgets().
*/
- int childCount( const TQObject *parent, const char *objName )
+ int childCount( const TQObject *tqparent, const char *objName )
{
- TQObjectList *list = parent->queryList( 0, objName, false, false );
+ TQObjectList *list = tqparent->queryList( 0, objName, false, false );
if ( !list )
return 0;
const int count = list->count();
@@ -302,7 +302,7 @@ TQString KMail::RuleWidgetHandlerManager::value( const TQCString& field,
if ( !val.isEmpty() )
return val;
}
- return TQString::null;
+ return TQString();
}
TQString KMail::RuleWidgetHandlerManager::prettyValue( const TQCString& field,
@@ -314,7 +314,7 @@ TQString KMail::RuleWidgetHandlerManager::prettyValue( const TQCString& field,
if ( !val.isEmpty() )
return val;
}
- return TQString::null;
+ return TQString();
}
void KMail::RuleWidgetHandlerManager::reset( TQWidgetStack *functionStack,
@@ -353,14 +353,14 @@ void KMail::RuleWidgetHandlerManager::update( const TQCString &field,
//-----------------------------------------------------------------------------
namespace {
- // FIXME (Qt >= 4.0):
+ // FIXME (TQt >= 4.0):
// This is a simplified and constified copy of TQObject::child(). According
- // to a comment in tqobject.h TQObject::child() will be made const in Qt 4.0.
- // So once we require Qt 4.0 this can be removed.
- TQObject* QObject_child_const( const TQObject *parent,
+ // to a comment in tqobject.h TQObject::child() will be made const in TQt 4.0.
+ // So once we require TQt 4.0 this can be removed.
+ TQObject* TQObject_child_const( const TQObject *tqparent,
const char *objName )
{
- const TQObjectList *list = parent->children();
+ const TQObjectList *list = tqparent->tqchildren();
if ( !list )
return 0;
@@ -472,9 +472,9 @@ namespace {
KMSearchRule::Function TextRuleWidgetHandler::currentFunction( const TQWidgetStack *functionStack ) const
{
const TQComboBox *funcCombo =
- dynamic_cast<TQComboBox*>( QObject_child_const( functionStack,
+ dynamic_cast<TQComboBox*>( TQObject_child_const( functionStack,
"textRuleFuncCombo" ) );
// FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<TQComboBox*>( functionStack->child( "textRuleFuncCombo",
// 0, false ) );
if ( funcCombo ) {
@@ -499,13 +499,13 @@ namespace {
TQString TextRuleWidgetHandler::currentValue( const TQWidgetStack *valueStack,
KMSearchRule::Function func ) const
{
- // here we gotta check the combobox which tqcontains the categories
+ // here we gotta check the combobox which contains the categories
if ( func == KMSearchRule::FuncIsInCategory ||
func == KMSearchRule::FuncIsNotInCategory ) {
const TQComboBox *combo=
- dynamic_cast<TQComboBox*>( QObject_child_const( valueStack,
+ dynamic_cast<TQComboBox*>( TQObject_child_const( valueStack,
"categoryCombo" ) );
// FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<TQComboBox*>( valueStack->child( "categoryCombo",
// 0, false ) );
if ( combo ) {
@@ -514,15 +514,15 @@ namespace {
else {
kdDebug(5006) << "TextRuleWidgetHandler::currentValue: "
"categoryCombo not found." << endl;
- return TQString::null;
+ return TQString();
}
}
//in other cases of func it is a lineedit
const RegExpLineEdit *lineEdit =
- dynamic_cast<RegExpLineEdit*>( QObject_child_const( valueStack,
+ dynamic_cast<RegExpLineEdit*>( TQObject_child_const( valueStack,
"regExpLineEdit" ) );
// FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<RegExpLineEdit*>( valueStack->child( "regExpLineEdit",
// 0, false ) );
if ( lineEdit ) {
@@ -533,7 +533,7 @@ namespace {
"regExpLineEdit not found." << endl;
// or anything else, like addressbook
- return TQString::null;
+ return TQString();
}
//---------------------------------------------------------------------------
@@ -794,9 +794,9 @@ namespace {
KMSearchRule::Function MessageRuleWidgetHandler::currentFunction( const TQWidgetStack *functionStack ) const
{
const TQComboBox *funcCombo =
- dynamic_cast<TQComboBox*>( QObject_child_const( functionStack,
+ dynamic_cast<TQComboBox*>( TQObject_child_const( functionStack,
"messageRuleFuncCombo" ) );
// FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<TQComboBox*>( functionStack->child( "messageRuleFuncCombo",
// 0, false ) );
if ( funcCombo ) {
@@ -825,9 +825,9 @@ namespace {
KMSearchRule::Function ) const
{
const RegExpLineEdit *lineEdit =
- dynamic_cast<RegExpLineEdit*>( QObject_child_const( valueStack,
+ dynamic_cast<RegExpLineEdit*>( TQObject_child_const( valueStack,
"regExpLineEdit" ) );
// FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<RegExpLineEdit*>( valueStack->child( "regExpLineEdit",
// 0, false ) );
if ( lineEdit ) {
@@ -837,7 +837,7 @@ namespace {
kdDebug(5006) << "MessageRuleWidgetHandler::currentValue: "
"regExpLineEdit not found." << endl;
- return TQString::null;
+ return TQString();
}
//---------------------------------------------------------------------------
@@ -847,7 +847,7 @@ namespace {
const TQWidgetStack *valueStack ) const
{
if ( !handlesField( field ) )
- return TQString::null;
+ return TQString();
KMSearchRule::Function func = currentFunction( functionStack );
if ( func == KMSearchRule::FuncHasAttachment )
@@ -865,7 +865,7 @@ namespace {
const TQWidgetStack *valueStack ) const
{
if ( !handlesField( field ) )
- return TQString::null;
+ return TQString();
KMSearchRule::Function func = currentFunction( functionStack );
if ( func == KMSearchRule::FuncHasAttachment )
@@ -1068,9 +1068,9 @@ namespace {
KMSearchRule::Function StatusRuleWidgetHandler::currentFunction( const TQWidgetStack *functionStack ) const
{
const TQComboBox *funcCombo =
- dynamic_cast<TQComboBox*>( QObject_child_const( functionStack,
+ dynamic_cast<TQComboBox*>( TQObject_child_const( functionStack,
"statusRuleFuncCombo" ) );
// FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<TQComboBox*>( functionStack->child( "statusRuleFuncCombo",
// 0, false ) );
if ( funcCombo ) {
@@ -1098,9 +1098,9 @@ namespace {
int StatusRuleWidgetHandler::currenStatusValue( const TQWidgetStack *valueStack ) const
{
const TQComboBox *statusCombo =
- dynamic_cast<TQComboBox*>( QObject_child_const( valueStack,
+ dynamic_cast<TQComboBox*>( TQObject_child_const( valueStack,
"statusRuleValueCombo" ) );
// FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<TQComboBox*>( valueStack->child( "statusRuleValueCombo",
// 0, false ) );
if ( statusCombo ) {
@@ -1119,13 +1119,13 @@ namespace {
const TQWidgetStack *valueStack ) const
{
if ( !handlesField( field ) )
- return TQString::null;
+ return TQString();
const int status = currenStatusValue( valueStack );
if ( status != -1 )
return TQString::tqfromLatin1( KMail::StatusValues[ status ].text );
else
- return TQString::null;
+ return TQString();
}
//---------------------------------------------------------------------------
@@ -1135,13 +1135,13 @@ namespace {
const TQWidgetStack *valueStack ) const
{
if ( !handlesField( field ) )
- return TQString::null;
+ return TQString();
const int status = currenStatusValue( valueStack );
if ( status != -1 )
return i18n( KMail::StatusValues[ status ].text );
else
- return TQString::null;
+ return TQString();
}
//---------------------------------------------------------------------------
@@ -1323,9 +1323,9 @@ namespace {
KMSearchRule::Function NumericRuleWidgetHandler::currentFunction( const TQWidgetStack *functionStack ) const
{
const TQComboBox *funcCombo =
- dynamic_cast<TQComboBox*>( QObject_child_const( functionStack,
+ dynamic_cast<TQComboBox*>( TQObject_child_const( functionStack,
"numericRuleFuncCombo" ) );
// FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<TQComboBox*>( functionStack->child( "numericRuleFuncCombo",
// 0, false ) );
if ( funcCombo ) {
@@ -1353,9 +1353,9 @@ namespace {
TQString NumericRuleWidgetHandler::currentValue( const TQWidgetStack *valueStack ) const
{
const KIntNumInput *numInput =
- dynamic_cast<KIntNumInput*>( QObject_child_const( valueStack,
+ dynamic_cast<KIntNumInput*>( TQObject_child_const( valueStack,
"KIntNumInput" ) );
// FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<KIntNumInput*>( valueStack->child( "KIntNumInput",
// 0, false ) );
if ( numInput ) {
@@ -1364,7 +1364,7 @@ namespace {
else
kdDebug(5006) << "NumericRuleWidgetHandler::currentValue: "
"KIntNumInput not found." << endl;
- return TQString::null;
+ return TQString();
}
//---------------------------------------------------------------------------
@@ -1374,7 +1374,7 @@ namespace {
const TQWidgetStack *valueStack ) const
{
if ( !handlesField( field ) )
- return TQString::null;
+ return TQString();
return currentValue( valueStack );
}
@@ -1386,7 +1386,7 @@ namespace {
const TQWidgetStack *valueStack ) const
{
if ( !handlesField( field ) )
- return TQString::null;
+ return TQString();
return currentValue( valueStack );
}
@@ -228,12 +228,12 @@ void KMail::RuleWidgetHandlerManager::unregisterHandler( const RuleWidgetHandler
}
namespace {
- /** Returns the number of immediate children of parent with the given object
+ /** Returns the number of immediate tqchildren of tqparent with the given object
name. Used by RuleWidgetHandlerManager::createWidgets().
*/
@@ -472,9 +472,9 @@ namespace {
"textRuleFuncCombo" ) );
- // FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
+ // FIXME (TQt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<TQComboBox*>( functionStack->child( "textRuleFuncCombo",
// 0, false ) );
@@ -499,13 +499,13 @@ namespace {
"categoryCombo" ) );
- // FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
+ // FIXME (TQt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<TQComboBox*>( valueStack->child( "categoryCombo",
// 0, false ) );
@@ -514,15 +514,15 @@ namespace {
"regExpLineEdit" ) );
- // FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
+ // FIXME (TQt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<RegExpLineEdit*>( valueStack->child( "regExpLineEdit",
// 0, false ) );
@@ -794,9 +794,9 @@ namespace {
"messageRuleFuncCombo" ) );
- // FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
+ // FIXME (TQt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<TQComboBox*>( functionStack->child( "messageRuleFuncCombo",
// 0, false ) );
@@ -825,9 +825,9 @@ namespace {
"regExpLineEdit" ) );
- // FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
+ // FIXME (TQt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<RegExpLineEdit*>( valueStack->child( "regExpLineEdit",
// 0, false ) );
@@ -1068,9 +1068,9 @@ namespace {
"statusRuleFuncCombo" ) );
- // FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
+ // FIXME (TQt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<TQComboBox*>( functionStack->child( "statusRuleFuncCombo",
// 0, false ) );
@@ -1098,9 +1098,9 @@ namespace {
"statusRuleValueCombo" ) );
- // FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
+ // FIXME (TQt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<TQComboBox*>( valueStack->child( "statusRuleValueCombo",
// 0, false ) );
@@ -1323,9 +1323,9 @@ namespace {
"numericRuleFuncCombo" ) );
- // FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
+ // FIXME (TQt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<TQComboBox*>( functionStack->child( "numericRuleFuncCombo",
// 0, false ) );
@@ -1353,9 +1353,9 @@ namespace {
"KIntNumInput" ) );
- // FIXME (Qt >= 4.0): Use the following when TQObject::child() is const.
+ // FIXME (TQt >= 4.0): Use the following when TQObject::child() is const.
// dynamic_cast<KIntNumInput*>( valueStack->child( "KIntNumInput",
// 0, false ) );